Package: cyclocomp
Title: Cyclomatic Complexity of R Code
Version: 1.1.2
Authors@R: 
    person("Gabor", "Csardi", , "csardi.gabor@gmail.com", role = c("aut", "cre"))
Description: Cyclomatic complexity is a software metric (measurement),
    used to indicate the complexity of a program. It is a quantitative
    measure of the number of linearly independent paths through a
    program's source code. It was developed by Thomas J. McCabe, Sr. in
    1976.
License: MIT + file LICENSE
URL: https://github.com/gaborcsardi/cyclocomp
BugReports: https://github.com/gaborcsardi/cyclocomp/issues
Imports: callr, crayon, desc, remotes, withr
Suggests: processx, testthat (>= 3.0.0)
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2026-03-11 09:39:58 UTC; gaborcsardi
Author: Gabor Csardi [aut, cre]
Maintainer: Gabor Csardi <csardi.gabor@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-11 10:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 03:16:52 UTC; unix
