# Generated by roxygen2: do not edit by hand

export(cyclocomp)
export(cyclocomp_package)
export(cyclocomp_package_dir)
export(cyclocomp_q)
importFrom(callr,r)
importFrom(callr,rcmd_safe)
importFrom(crayon,red)
importFrom(crayon,underline)
importFrom(crayon,yellow)
importFrom(desc,desc_get)
importFrom(remotes,install_local)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(withr,with_dir)
